==> plain_tailwind-0.15.0.tar.gz: plain_tailwind-0.15.0/plain/tailwind/CHANGELOG.md <==
# plain-tailwind changelog

## [0.15.0](https://github.com/dropseed/plain/releases/plain-tailwind@0.15.0) (2025-09-19)

### What's changed

- Added `plain-tailwind` standalone script for running Tailwind installation separately from Plain ([a9d1ab6](https://github.com/dropseed/plain/commit/a9d1ab6c18))

### Upgrade instructions

- No changes required

## [0.14.0](https://github.com/dropseed/plain/releases/plain-tailwind@0.14.0) (2025-09-19)

### What's changed

- Added new `plain tailwind version` command to display the currently installed Tailwind CSS version ([4679a42](https://github.com/dropseed/plain/commit/4679a423b6))
- Minimum Python version requirement updated from 3.11 to 3.13 ([d86e307](https://github.com/dropseed/plain/commit/d86e307efb))

### Upgrade instructions

- Update your Python environment to Python 3.13 or later

## [0.13.3](https://github.com/dropseed/plain/releases/plain-tailwind@0.13.3) (2025-09-03)

### What's changed

- Comprehensive README update with improved documentation structure, table of contents, and detailed usage examples ([4ebecd1](https://github.com/dropseed/plain/commit/4ebecd1856))
- Added AGENTS.md file with guidance for conditional Tailwind styling using `data-` attributes ([df3edbf](https://github.com/dropseed/plain/commit/df3edbf0bd))

### Upgrade instructions

- No changes required

## [0.13.2](https://github.com/dropseed/plain/releases/plain-tailwind@0.13.2) (2025-07-07)

### What's changed

- The CLI now shows a progress bar while downloading the Tailwind standalone binary, so long downloads no longer appear to hang ([ec637aa](https://github.com/dropseed/plain/commit/ec637aa)).

### Upgrade instructions

- No changes required

## [0.13.1](https://github.com/dropseed/plain/releases/plain-tailwind@0.13.1) (2025-06-26)

### What's changed

- No user-facing changes in this patch release. Internal housekeeping of the CHANGELOG file only ([e1f5dd3](https://github.com/dropseed/plain/commit/e1f5dd3e4612)).

### Upgrade instructions

- No changes required

==> plain_tailwind-0.15.3.tar.gz: plain_tailwind-0.15.3/plain/tailwind/CHANGELOG.md <==
# plain-tailwind changelog

## [0.15.3](https://github.com/dropseed/plain/releases/plain-tailwind@0.15.3) (2025-10-12)

### What's changed

- Removed outdated reference to Heroku buildpack in documentation ([ee4710a](https://github.com/dropseed/plain/commit/ee4710af07))

### Upgrade instructions

- No changes required

## [0.15.2](https://github.com/dropseed/plain/releases/plain-tailwind@0.15.2) (2025-10-06)

### What's changed

- Added comprehensive type annotations to improve IDE and type checker support ([9b6882b](https://github.com/dropseed/plain/commit/9b6882bae7))

### Upgrade instructions

- No changes required

## [0.15.1](https://github.com/dropseed/plain/releases/plain-tailwind@0.15.1) (2025-09-25)

### What's changed

- Improved Tailwind download performance by using larger chunk sizes (8MB) and optimized HTTP connection pooling ([9bf4eca](https://github.com/dropseed/plain/commit/9bf4eca61e))

### Upgrade instructions

- No changes required

## [0.15.0](https://github.com/dropseed/plain/releases/plain-tailwind@0.15.0) (2025-09-19)

### What's changed

- Added `plain-tailwind` standalone script for running Tailwind installation separately from Plain ([a9d1ab6](https://github.com/dropseed/plain/commit/a9d1ab6c18))

### Upgrade instructions

- No changes required

## [0.14.0](https://github.com/dropseed/plain/releases/plain-tailwind@0.14.0) (2025-09-19)

### What's changed

- Added new `plain tailwind version` command to display the currently installed Tailwind CSS version ([4679a42](https://github.com/dropseed/plain/commit/4679a423b6))
- Minimum Python version requirement updated from 3.11 to 3.13 ([d86e307](https://github.com/dropseed/plain/commit/d86e307efb))

### Upgrade instructions

- Update your Python environment to Python 3.13 or later

## [0.13.3](https://github.com/dropseed/plain/releases/plain-tailwind@0.13.3) (2025-09-03)

### What's changed

- Comprehensive README update with improved documentation structure, table of contents, and detailed usage examples ([4ebecd1](https://github.com/dropseed/plain/commit/4ebecd1856))
- Added AGENTS.md file with guidance for conditional Tailwind styling using `data-` attributes ([df3edbf](https://github.com/dropseed/plain/commit/df3edbf0bd))

### Upgrade instructions

- No changes required

## [0.13.2](https://github.com/dropseed/plain/releases/plain-tailwind@0.13.2) (2025-07-07)

### What's changed

- The CLI now shows a progress bar while downloading the Tailwind standalone binary, so long downloads no longer appear to hang ([ec637aa](https://github.com/dropseed/plain/commit/ec637aa)).

### Upgrade instructions

- No changes required

## [0.13.1](https://github.com/dropseed/plain/releases/plain-tailwind@0.13.1) (2025-06-26)

### What's changed

- No user-facing changes in this patch release. Internal housekeeping of the CHANGELOG file only ([e1f5dd3](https://github.com/dropseed/plain/commit/e1f5dd3e4612)).

### Upgrade instructions

- No changes required
